@@ -40,6 +40,9 @@
 /* A70903 : for burn_scsi_setup_drive() */
 #include "spc.h"
 
+/* A90815 : for mmc_obtain_profile_name() */
+#include "mmc.h"
+
 #include "libdax_msgs.h"
 extern struct libdax_msgs *libdax_messenger;
 
@@ -530,6 +533,22 @@ int burn_drive_release_fl(struct burn_drive *d, int flag)
 }
 
 
+/* API */
+/* ts A90824
+   @param flag bit0= wake up (else start snoozing)
+*/
+int burn_drive_snooze(struct burn_drive *d, int flag)
+{
+	if (d->drive_role != 1)
+		return 0;
+	if (flag & 1)
+		d->start_unit(d);
+	else
+		d->stop_unit(d);
+	return 1;
+}
+
+
 /* API */
 void burn_drive_release(struct burn_drive *d, int le)
 {
@@ -1889,11 +1908,16 @@ int burn_disc_read_atip(struct burn_drive *d)
 	}
 	if(d->drive_role != 1)
 		return 0;
-	if (d->current_profile == -1 || d->current_is_cd_profile) {
+	if ((d->current_profile == -1 || d->current_is_cd_profile)
+	    && (d->mdata->cdrw_write || d->current_profile != 0x08)) {
 		d->read_atip(d);
 		/* >>> some control of success would be nice :) */
 	} else {
-		/* mmc5r03c.pdf 6.26.3.6.3 : ATIP is undefined for non-CD */;
+		/* mmc5r03c.pdf 6.26.3.6.3 : ATIP is undefined for non-CD
+		   (and it seems meaningless for non-burners).
+		   ts A90823: Pseudo-CD U3 memory stick stalls with ATIP.
+		              It is !cdrw_write and profile is 0x08.
+		*/
 		return 0;
 	}
 	return 1;
@@ -2001,6 +2025,30 @@ int burn_disc_get_profile(struct burn_drive *d, int *pno, char name[80])
 }
 
 
+/* ts A90815 : New API function */
+int burn_drive_get_all_profiles(struct burn_drive *d, int *num_profiles,
+				int profiles[64], char is_current[64])
+{
+	int i;
+
+	*num_profiles = d->num_profiles;
+	for (i = 0; i < d->num_profiles; i++) {
+		profiles[i] = (d->all_profiles[i * 4] << 8) |
+				d->all_profiles[i * 4 + 1];
+		is_current[i] = d->all_profiles[i * 4 + 2] & 1;
+	}
+	return 1;
+}
+
+
+/* ts A90815 : New API function */
+int burn_obtain_profile_name(int profile_number, char name[80])
+{
+	strcpy(name, mmc_obtain_profile_name(profile_number));
+	return(name[0] != 0);
+}
+
+
 /* ts A61223 : New API function */
 int burn_drive_wrote_well(struct burn_drive *d)
 {
